# -*- coding: utf-8 -*-

__title__ = 'scrim'
__author__ = 'Dan Bradham'
__email__ = 'danielbradham@gmail.com'
__license__ = 'MIT'
__url__ = 'https://github.com/danbradham/scrim.git'
__description__ = 'Opaque Python CLI Wrapper'
__version__ = '0.0.1'

from .api import *
from .globals import *
from .utils import *
